@@ -15,8 +15,8 @@ fn bench_sigverify(bencher: &mut Bencher) {
     // generate packet vector
     let mut batches = to_packets_chunked(&std::iter::repeat(tx).take(128).collect::<Vec<_>>(), 128);
 
-    let recycler = Recycler::new_without_limit("");
-    let recycler_out = Recycler::new_without_limit("");
+    let recycler = Recycler::default();
+    let recycler_out = Recycler::default();
     // verify packets
     bencher.iter(|| {
         let _ans = sigverify::ed25519_verify(&mut batches, &recycler, &recycler_out);
@@ -28,12 +28,11 @@ fn bench_get_offsets(bencher: &mut Bencher) {
     let tx = test_tx();
 
     // generate packet vector
-    let mut batches =
-        to_packets_chunked(&std::iter::repeat(tx).take(1024).collect::<Vec<_>>(), 1024);
+    let batches = to_packets_chunked(&std::iter::repeat(tx).take(1024).collect::<Vec<_>>(), 1024);
 
-    let recycler = Recycler::new_without_limit("");
+    let recycler = Recycler::default();
     // verify packets
     bencher.iter(|| {
-        let _ans = sigverify::generate_offsets(&mut batches, &recycler);
+        let _ans = sigverify::generate_offsets(&batches, &recycler);
     })
 }
